import React, { useState, useEffect } from "react";
import { useScrollDirection } from "@hooks/useScrollDirection";
import { IHeader } from "@interfaces/IHeader";
import { LogoResponsive } from "@components/LogoResponsive";
import { MobileMenu } from "@components/Header/components/MobileMenu";
import { HamburgerButton } from "./components/HamburgerButton";
import { TopBar } from "@components/TopBar";
import { Toolbar } from "@components/Toolbar";
import { LanguageSelector } from "@components/LanguageSelector";
import { LinkOrContainer } from "@components/LinkOrContainer";
import { FabCityHamburgLogo } from "@components/FabCityHamburgLogo";

export const Header: React.FC<
  IHeader & {
    backgroundImageClasses?: string;
    customLogo?: [string, string];
    customLogoAlt?: [string, string];
    logoAlwaysInTopBar?: boolean;
  }
> = ({
  className,
  topBarItems,
  toolBarItems,
  extendedToolBarItems,
  onClickHamburger,
  languages,
  onChangeLanguage,
  selectedLanguage,
  onSearch,
  disableAnimation,
  backgroundImageClasses,
  itemsAlwaysLight,
  hideSearchIcon,
  logoLinkTarget = "/",
  logoAlwaysInTopBar,
  customLogo,
  customLogoAlt,
  logoClassName = "",
}) => {
  const [shouldShowHeader, setShouldShowHeader] = useState(true);
  const [isMobileOpen, setIsMobileOpen] = useState(false);
  const scrollDirection = useScrollDirection();



  useEffect(() => {
    if (!isMobileOpen && !disableAnimation) {
      setShouldShowHeader(!scrollDirection);
    }
  }, [scrollDirection]);

  const handleMobileMenuClick = () => {
    setIsMobileOpen(!isMobileOpen);
    onClickHamburger && onClickHamburger();
  };

  const alwaysLight = itemsAlwaysLight || isMobileOpen;

  const CustomLogo = ({
    dark = true,
    className = "",
  }: {
    dark?: boolean;
    className?: string;
  }) =>
    customLogo?.[0] ? (
      <img
        className={`h-full object-contain ${className}`}
        src={dark ? customLogo?.[0] : customLogo?.[1]}
        alt={dark ? customLogoAlt?.[0] : customLogoAlt?.[0]}
      />
    ) : null;

  const getTopBarLogo = (
    logoAlwaysInTopBar?: boolean,
    customLogo?: React.ReactNode,
  ) => {
    let topBarLogo;
    if (logoAlwaysInTopBar && customLogo) {
      topBarLogo = (
        <LinkOrContainer href={logoLinkTarget}>
          <CustomLogo className={logoClassName} />
        </LinkOrContainer>
      );
    } else if (logoAlwaysInTopBar && !customLogo) {
      topBarLogo = (
        <LinkOrContainer href={logoLinkTarget}>
          <FabCityHamburgLogo
            lightColor={false}
            monotone={false}
            className={`!h-6 block`}
          />
        </LinkOrContainer>
      );
    } else {
      topBarLogo = <></>;
    }

    return topBarLogo;
  };

  return (
    <div
      className={`w-full fixed sm:h-auto z-50 transition-all ease-in-out left-0 duration-500 ${
        isMobileOpen ? "!h-screen" : ""
      } ${
        backgroundImageClasses
          ? isMobileOpen
            ? "bg-grey-900"
            : backgroundImageClasses
          : isMobileOpen
          ? "bg-grey-900"
          : "bg-white lg:bg-transparent"
      } ${shouldShowHeader ? "top-0" : "-top-64"} ${
        className ? className : ""
      }`}
    >
      <TopBar
        items={topBarItems}
        onChangeLanguage={onChangeLanguage}
        selectedLanguage={selectedLanguage}
        languages={languages}
        onSearch={(keyword) => onSearch && onSearch(keyword)}
        light={itemsAlwaysLight}
        hideSearchIcon={hideSearchIcon}
        customLogo={getTopBarLogo(logoAlwaysInTopBar, customLogo)}
      />
      <div className="container flex justify-between items-center py-3 lg:py-6">
        {customLogo && (
          <LinkOrContainer
            className={`w-auto lg:w-36 lg:h-auto h-10 z-10 overflow-hidden lg:overflow-auto ${
              logoAlwaysInTopBar ? "lg:hidden" : ""
            }`}
            href={logoLinkTarget}
          >
            <CustomLogo dark={!isMobileOpen} className={logoClassName} />
          </LinkOrContainer>
        )}
        {!customLogo && (
          <LogoResponsive
            desktopLight={true}
            mobileLight={alwaysLight}
            desktopMonotone={true}
            mobileMonotone={false}
            desktopClasses={logoAlwaysInTopBar ? "!hidden" : ""}
            href={logoLinkTarget}
          />
        )}
        <div className="flex items-center gap-7">
          {languages?.length && (
            <LanguageSelector
              isMobileOpen={isMobileOpen}
              onChangeLanguage={onChangeLanguage}
              selectedLanguage={selectedLanguage}
              languages={languages}
              light={alwaysLight}
              horizontal
            />
          )}
          <HamburgerButton
            onClick={handleMobileMenuClick}
            light={alwaysLight}
          />
        </div>
        {toolBarItems && (
          <Toolbar isMobileOpen={isMobileOpen} items={toolBarItems} />
        )}
      </div>
      {/* Toolbar in mobile menu */}
      {toolBarItems && (
        <Toolbar
          isMobileOpen={isMobileOpen}
          items={toolBarItems}
          extendedToolbarItems={extendedToolBarItems}
          className="lg:hidden"
        />
      )}

      <MobileMenu isMobileOpen={isMobileOpen} data={topBarItems} />
    </div>
  );
};
